Plots an occurrence data frame with points as a map using ggplot
Source:R/map.R
occs_ggmap_points.RdPlots an occurrence data frame with points as a map using ggplot
R/map.R
occs_ggmap_points.RdPlots an occurrence data frame with points as a map using ggplot