Skip to contents

Converts a raster grid into a dataframe of points which can be plotted with ggplot

Usage

r2df_points(r)

Arguments

r

a terra SpatRaster

Value

a data frame with cell grid coordinates and values in columns x, y, z