Converts a raster grid into a dataframe of closed polygons which can be plotted with ggplot
Source:R/convert.R
r2df_polygons.RdConverts a raster grid into a dataframe of closed polygons which can be plotted with ggplot
R/convert.R
r2df_polygons.RdConverts a raster grid into a dataframe of closed polygons which can be plotted with ggplot