Return all grid cells identifiers where the specified species occurs
Usage
which_cells(.presence = default_presence(), .latinname = default_species())Return all grid cells identifiers where the specified species occurs
which_cells(.presence = default_presence(), .latinname = default_species())