aquamaps.org uses internal identifiers for species, and this function scrapes the website and resolves a given latinname into one of these identifiers, which can be used to get a specific nativerange map in the case there are several available for a specific given latinname
Usage
get_am_name_uris(latinname = default_species())