This function downloads a dropbox folder into the given destination directory.
Usage
get_dropbox_file(pubshare, destfile = tempfile())This function downloads a dropbox folder into the given destination directory.
get_dropbox_file(pubshare, destfile = tempfile())