aquamaps.org provides native range data downloads on a per species basis and this function scrapes the website for this information and returns it as a dataframe
Usage
nativerange(latinname = default_species(), identifier)aquamaps.org provides native range data downloads on a per species basis and this function scrapes the website for this information and returns it as a dataframe
nativerange(latinname = default_species(), identifier)